---
jupyter:
  kernelspec:
    display_name: Python 3
    language: python
    name: python3
---

```raw_mimetype="text/latex"
$1+1$
```

```raw_mimetype="text/restructuredtext"
:math:`1+1`
```

```raw_mimetype="text/html"
<b>Bold text<b>
```

```raw_mimetype="text/markdown"
**Bold text**
```

```raw_mimetype="text/x-python"
1 + 1
```

```
Not formatted
```
